"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useStreamVideoStoreValue = exports.useStreamVideoStoreSetState = exports.StreamVideoStoreProvider = void 0;
var _react = _interopRequireWildcard(require("react"));
function _interopRequireWildcard(e, t) { if ("function" == typeof WeakMap) var r = new WeakMap(), n = new WeakMap(); return (_interopRequireWildcard = function (e, t) { if (!t && e && e.__esModule) return e; var o, i, f = { __proto__: null, default: e }; if (null === e || "object" != typeof e && "function" != typeof e) return f; if (o = t ? n : r) { if (o.has(e)) return o.get(e); o.set(e, f); } for (const t in e) "default" !== t && {}.hasOwnProperty.call(e, t) && ((i = (o = Object.defineProperty) && Object.getOwnPropertyDescriptor(e, t)) && (i.get || i.set) ? o(f, t, i) : f[t] = e[t]); return f; })(e, t); }
/**
 * Creates a Atomic store context with a provider and hooks to access the store
 * Atomic means that each value in the store updates state separately using useStoreValue hook
 * Extremely minimalistic implementation of Jotai's store context
 * @param initialState - the initial state of the store
 * @returns - {Provider, useStoreValue, useStoreSetState}
 */
function createStoreContext(initialState) {
  // returns unsubscribe function

  function useStoreData() {
    const storeRef = (0, _react.useRef)(initialState);
    const getSnapshot = (0, _react.useRef)(() => storeRef.current).current;
    const subscribersRef = (0, _react.useRef)([]);
    const setState = (0, _react.useRef)(partialStateOrFunc => {
      if (typeof partialStateOrFunc === 'function') {
        const value = partialStateOrFunc(storeRef.current);
        storeRef.current = {
          ...storeRef.current,
          ...value
        };
      } else {
        storeRef.current = {
          ...storeRef.current,
          ...partialStateOrFunc
        };
      }
      subscribersRef.current.forEach(callback => callback());
    }).current;
    const subscribe = (0, _react.useRef)(callback => {
      subscribersRef.current.push(callback);
      return () => subscribersRef.current.filter(cb => cb !== callback);
    }).current;
    return {
      getSnapshot,
      setState,
      subscribe
    };
  }
  const StoreContext = /*#__PURE__*/(0, _react.createContext)(null);
  function Provider(props) {
    const value = useStoreData();
    return /*#__PURE__*/_react.default.createElement(StoreContext.Provider, {
      value: value
    }, props.children);
  }

  /**
   * @param selector
   * @returns
   *
   * @category Client State
   */
  function useStoreValue(selector) {
    const store = (0, _react.useContext)(StoreContext);
    if (!store) {
      throw new Error('Store not found');
    }
    const [state, setState] = (0, _react.useState)(selector(store.getSnapshot()));
    (0, _react.useEffect)(() => store.subscribe(() => setState(selector(store.getSnapshot()))), [selector, store]);
    return state;
  }

  /**
   *
   * @returns
   *
   * @category Client State
   */
  function useStoreSetState() {
    const store = (0, _react.useContext)(StoreContext);
    if (!store) {
      throw new Error('Store not found');
    }
    return store.setState;
  }
  return {
    Provider,
    useStoreValue,
    useStoreSetState
  };
}

/**
 * Exclude types from documentation site, but we should still add doc comments
 * @internal
 */

const {
  Provider: StreamVideoStoreProvider,
  useStoreValue: useStreamVideoStoreValue,
  useStoreSetState: useStreamVideoStoreSetState
} = createStoreContext({
  videoDevices: [],
  audioDevices: [],
  currentVideoDevice: undefined,
  currentAudioDevice: undefined
});
exports.useStreamVideoStoreSetState = useStreamVideoStoreSetState;
exports.useStreamVideoStoreValue = useStreamVideoStoreValue;
exports.StreamVideoStoreProvider = StreamVideoStoreProvider;
//# sourceMappingURL=StreamVideoContext.js.map