"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useCallMediaStreamCleanup = void 0;
var _videoClient = require("@stream-io/video-client");
var _videoReactBindings = require("@stream-io/video-react-bindings");
var _react = require("react");
/**
 * This hook is meant to be used in Lobby view or equivalent.
 * It will cleanup the media stream on unmount if call is not meant to be joined.
 */
const useCallMediaStreamCleanup = () => {
  const call = (0, _videoReactBindings.useCall)();
  // keeping a reference of call to handle cleanup media stream only on unmount
  const callRef = (0, _react.useRef)(call);
  callRef.current = call;
  (0, _react.useEffect)(() => {
    return () => {
      const mediaStream = callRef.current?.camera.state.mediaStream;
      if (mediaStream && !(callRef.current?.state.callingState === _videoClient.CallingState.JOINED || callRef.current?.state.callingState === _videoClient.CallingState.JOINING)) {
        (0, _videoClient.getLogger)(['useCallMediaStreamCleanup'])('debug', 'Cleaning up camera media stream');
        // we cleanup media stream only if call is not joined or joining
        (0, _videoClient.disposeOfMediaStream)(mediaStream);
      }
    };
  }, []);
};
exports.useCallMediaStreamCleanup = useCallMediaStreamCleanup;
//# sourceMappingURL=useCallMediaStreamCleanup.js.map